@@ -85,7 +85,7 @@ class DataVarsSerializer(ClassSerializer):
 
     def getChoice(self, var_obj):
         if ("choice" in var_obj.type or "file" in var_obj.type or
-                var_obj.element == "radio"):
+                    var_obj.element == "radio"):
             choice, comments = var_obj.parent.ChoiceAndComments(var_obj.name)
             return self.arrayString(choice), self.arrayString(comments)
         else:
@@ -227,7 +227,7 @@ class Field(DataVarsSerializer):
             self.element = varObj.element or self.elementByType(self.type)
             self.label = varObj.label or varObj.name
             if (not onlyhelp or varObj.syntax or self.type == "table" or
-                    self.type == "bool"):
+                        self.type == "bool"):
                 if inbrief:
                     self.uncompatible = ""
                 else:
@@ -329,12 +329,12 @@ class GroupField(DataVarsSerializer):
                                                  element="expert",
                                                  label=info['expert_label'],
                                                  value="open"))
-                        for varname in info['expert']:
-                            inbrief = brief and varname in info['brief_force']
+                        for varname_ in info['expert']:
+                            inbrief = brief and varname_ in info['brief_force']
                             if (brief and 'hide' in info and
-                                    varname in info['hide']):
+                                        varname_ in info['hide']):
                                 continue
-                            varObj = dv.getInfo(varname)
+                            varObj = dv.getInfo(varname_)
                             self.fields.append(Field(dv=dv, expert=True,
                                                      inbrief=inbrief,
                                                      briefmode=brief,
@@ -437,6 +437,7 @@ class ViewParams(ClassSerializer):
     onlyhelp = Boolean  # request params for only help
     clienttype = String  # type of client "gui","console"
 
+
 #########
 # MESSAGE
 #########
@@ -508,7 +509,7 @@ class CoreWsdl(CoreServiceInterface):
         """
         Общий алгоритм вызова действия
         """
-        if logicClass is None:
+        if not logicClass:
             logicClass = {}
         dv = self.get_cache(sid, method_name, "vars")
         try:
@@ -540,8 +541,9 @@ class CoreWsdl(CoreServiceInterface):
             objs = {}
             from calculate.core.server.func import CommonLink
 
-            for k, v in logicClass.items():
-                objs[k] = type("Logic", (CommonLink, v, object), {})()
+            if isinstance(logicClass, dict):
+                for k, v in logicClass.items():
+                    objs[k] = type("Logic", (CommonLink, v, object), {})()
             install_meth = type("CommonCore", (self.Common,
                                                actionClass, object), {})
             pid = self.startprocess(sid, target=install_meth,
@@ -605,7 +607,7 @@ class CoreWsdl(CoreServiceInterface):
             try:
                 # read all on one record
                 list_sid = pickle.load(fd)
-            except:
+            except (EOFError, KeyError, IOError):
                 break
             # find session id in sids file
             if cert_id == int(list_sid[1]):
@@ -619,7 +621,7 @@ class CoreWsdl(CoreServiceInterface):
             try:
                 # read out on 1 record
                 list_pid = pickle.load(fd)
-            except:
+            except (EOFError, KeyError, IOError):
                 break
             if sid == int(list_pid[0]):
                 if pid == int(list_pid[1]):
@@ -652,7 +654,7 @@ class CoreWsdl(CoreServiceInterface):
         if self.check_cert_pid(sid, pid):
             try:
                 results = self.glob_frame_list[pid]
-            except:
+            except (AttributeError, KeyError, IndexError):
                 return self.perm_denied
             len_glob_frame_list = len(self.glob_frame_list[pid])
             self.glob_process_dict[pid]['counter'] = len_glob_frame_list
