@@ -125,8 +125,9 @@ class ClApplication(Application):
         if params:
             if (hasattr(params, 'sid') and
                     (method_name in LoadedMethods.rightsMethods or
-                     method_name.endswith('_view') and
-                     method_name[:-5] in LoadedMethods.rightsMethods)):
+                             method_name.endswith('_view') and
+                                 method_name[
+                                 :-5] in LoadedMethods.rightsMethods)):
                 if not self.check_cert_sid(params.sid, curthread.server):
                     return 0
 
@@ -182,8 +183,8 @@ class ClApplication(Application):
                     if line.split()[0] == 'all':
                         find_flag = True
                         break
-                    #                if not find_flag:
-                    #                    return 1
+                        #                if not find_flag:
+                        #                    return 1
 
             for right_param in LoadedMethods.rightsMethods[method_name]:
                 flag = 0
